#
# spec file for package ghc-utf8-string
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name utf8-string
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.0.2
Release:        2.15
Summary:        Support for reading and writing UTF8 Strings
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
%endif

%description
A UTF8 layer for Strings. The utf8-string package provides operations for
encoding UTF8 strings to Word8 lists and back, and for reading and writing UTF8
without truncation.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.markdown

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Jan  4 2021 psimons@suse.com
- Update utf8-string to version 1.0.2.
  1.0.2
  - ----
  * Add fromChar
  * Add IsString UTF8 instance
  * Fixup documentation and tests
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Aug 31 2020 psimons@suse.com
- Update utf8-string to version 1.0.1.1 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Wed May 16 2018 psimons@suse.com
- Prefer the new %%license attribute over %%doc.
- Update Cabal file to revision 3.
  * add support for GHC 8.4.x
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Wed May  3 2017 psimons@suse.com
- Update to version 1.0.1.1 revision 2 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.0.1.1 revision 1 with cabal2obs.
* Mon Aug 31 2015 mimi.vx@gmail.com
- update to 1.0.1.1
  * fix build under older GHC
* Sun Aug 23 2015 mimi.vx@gmail.com
- update to 1.0.1
  * Improve the performance of Data.ByteString.Lazy.UTF8.fromString.
* Mon Apr 20 2015 mimi.vx@gmail.com
- update to version 1
  * Remove out all the old utf8 IO support. GHC supports utf8 now.
  * Performance tweaks
  * bytestring-in-base flag default to False
* Mon Oct 21 2013 sbahling@suse.com
- spec file: Add %%defattr(-,root,root,-) to %%files devel section
* Wed May 15 2013 peter.trommler@ohm-hochschule.de
- new cabal-rpm spec file template
  * no macros spanning multiple spec file sections
* Thu Jun  7 2012 peter.trommler@ohm-hochschule.de
- explicitly BuildRequire bytestring
- add summary and description
* Thu Jun  7 2012 herbert@graeber-clan.de
- updated for haskell platform 2012.2.0.0
  new spec file template generated by cabal2spec-0.25.5
* Wed Jan 18 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
